@@ -21,11 +21,13 @@ void add_read_structure(py::module& m); // read.cpp
 void add_cif_read(py::module& cif); // read.cpp
 void add_monlib(py::module& m); // monlib.cpp
 void add_alignment(py::module& m); // monlib.cpp
+void add_select(py::module& m); // monlib.cpp
 
 void add_misc(py::module& m) {
   using gemmi::Element;
   using gemmi::SmallStructure;
   using IT92 = gemmi::IT92<double>;
+  py::class_<IT92::Coef> pyIT92Coef(m, "IT92Coef");
   py::class_<Element>(m, "Element")
     .def(py::init<const std::string &>())
     .def(py::init<int>())
@@ -41,6 +43,7 @@ void add_misc(py::module& m) {
     .def_property_readonly("weight", &Element::weight)
     .def_property_readonly("covalent_r", &Element::covalent_r)
     .def_property_readonly("atomic_number", &Element::atomic_number)
+    .def_property_readonly("is_metal", &Element::is_metal)
     .def_property_readonly("it92", [](const Element& self) {
         return IT92::get_ptr(self.elem);
     }, py::return_value_policy::reference_internal)
@@ -58,13 +61,7 @@ void add_misc(py::module& m) {
     .def_readonly("element", &SmallStructure::Site::element)
     .def_readonly("charge", &SmallStructure::Site::charge)
     .def_readonly("disorder_group", &SmallStructure::Site::disorder_group)
-    .def_readonly("u11", &SmallStructure::Site::u11)
-    .def_readonly("u22", &SmallStructure::Site::u22)
-    .def_readonly("u33", &SmallStructure::Site::u33)
-    .def_readonly("u12", &SmallStructure::Site::u12)
-    .def_readonly("u13", &SmallStructure::Site::u13)
-    .def_readonly("u23", &SmallStructure::Site::u23)
-    .def("has_anisou", &SmallStructure::Site::has_anisou)
+    .def_readonly("aniso", &SmallStructure::Site::aniso)
     .def("orth", &SmallStructure::Site::orth)
     .def("__repr__", [](const SmallStructure::Site& self) {
         return "<gemmi.SmallStructure.Site " + self.label + ">";
@@ -92,9 +89,9 @@ void add_misc(py::module& m) {
         return "<gemmi.SmallStructure: " + std::string(self.name) + ">";
     });
 
-  py::class_<IT92::Coef>(m, "IT92Coef")
+  pyIT92Coef
     .def("calculate_sf", &IT92::Coef::calculate_sf, py::arg("stol2"))
-    .def("calculate_density", &IT92::Coef::calculate_density,
+    .def("calculate_density_iso", &IT92::Coef::calculate_density_iso,
          py::arg("r2"), py::arg("B"))
     ;
 
@@ -112,21 +109,23 @@ void add_misc(py::module& m) {
   m.def("expand_pdb_code_to_path", &gemmi::expand_pdb_code_to_path);
   m.def("expand_if_pdb_code", &gemmi::expand_if_pdb_code,
         py::arg("code"), py::arg("filetype")='M');
+  m.attr("hc") = py::float_(gemmi::hc());
 }
 
 PYBIND11_MODULE(gemmi, mg) {
-  mg.doc() = "General MacroMolecular I/O";
+  mg.doc() = "GEneral MacroMolecular I/O";
   mg.attr("__version__") = GEMMI_VERSION;
-  add_symmetry(mg);
-  add_grid(mg);
-  add_unitcell(mg);
-  add_hkl(mg);
-  add_misc(mg);
-  add_mol(mg);
-  add_monlib(mg);
-  add_alignment(mg);
-  add_read_structure(mg);
   py::module cif = mg.def_submodule("cif", "CIF file format");
   add_cif(cif);
+  add_symmetry(mg);
+  add_unitcell(mg);
+  add_misc(mg);
+  add_mol(mg);
+  add_grid(mg);
   add_cif_read(cif);
+  add_hkl(mg);
+  add_monlib(mg);
+  add_alignment(mg);
+  add_select(mg);
+  add_read_structure(mg);
 }
