@@ -95,6 +95,20 @@ expand_protein_one_letter_string(const std::string& s) {
 }
 
 void add_mol(py::module& m) {
+
+  // "Forward declaration" of python classes to avoid
+  // C++ signatures in docstrings
+  py::class_<AtomAddress> pyAtomAddress(m, "AtomAddress");
+  py::class_<ResidueId> pyResidueId(m, "ResidueId");
+  py::class_<Atom> pyAtom(m, "Atom");
+  py::class_<Residue, ResidueId> pyResidue(m, "Residue");
+  py::class_<Chain> pyChain(m, "Chain");
+  py::class_<Model> pyModel(m, "Model");
+  py::class_<SeqId> pySeqId(m, "SeqId");
+  py::class_<ResidueSpan> pyResidueSpan(m, "ResidueSpan");
+  py::class_<ResidueGroup, ResidueSpan> pyResidueGroup(m, "ResidueGroup");
+  py::class_<CraProxy> pyCraGenerator(m, "CraGenerator");
+
   py::class_<ResidueInfo>(m, "ResidueInfo")
     .def_readonly("one_letter_code", &ResidueInfo::one_letter_code)
     .def_readonly("hydrogen_count", &ResidueInfo::hydrogen_count)
@@ -183,7 +197,7 @@ void add_mol(py::module& m) {
     .value("Disulf", Connection::Type::Disulf)
     .value("Hydrog", Connection::Type::Hydrog)
     .value("MetalC", Connection::Type::MetalC)
-    .value("None",   Connection::Type::None);
+    .value("Unknown", Connection::Type::Unknown);
 
   py::class_<Connection>(m, "Connection")
     .def(py::init<>())
@@ -294,12 +308,14 @@ void add_mol(py::module& m) {
     .def("remove_ligands_and_waters",
          (void (*)(Structure&)) &remove_ligands_and_waters)
     .def("remove_empty_chains", (void (*)(Structure&)) &remove_empty_chains)
+    .def("shorten_chain_names", &shorten_chain_names)
+    .def("clone", [](const Structure& self) { return new Structure(self); })
     .def("__repr__", [](const Structure& self) {
         return tostr("<gemmi.Structure ", self.name, " with ",
                      self.models.size(), " model(s)>");
     });
 
-  py::class_<AtomAddress>(m, "AtomAddress")
+  pyAtomAddress
     .def(py::init<>())
     .def(py::init<const Chain&, const Residue&, const Atom&>())
     .def(py::init<const std::string&, const SeqId&, const std::string&,
@@ -324,11 +340,11 @@ void add_mol(py::module& m) {
         return tostr("<gemmi.CRA ", atom_str(self), '>');
     });
 
-  py::class_<Model>(m, "Model")
+  pyModel
     .def(py::init<std::string>())
     .def_readwrite("name", &Model::name)
     .def("__len__", [](const Model& self) { return self.chains.size(); })
-    .def("__iter__", [](const Model& self) {
+    .def("__iter__", [](Model& self) {
         return py::make_iterator(self.chains);
     }, py::keep_alive<0, 1>())
     .def("__getitem__", &get_child<Model, Chain>, py::arg("index"),
@@ -336,6 +352,7 @@ void add_mol(py::module& m) {
     .def("__getitem__", [](Model& self, const std::string& name) -> Chain& {
         return *impl::find_iter(self.chains, name);
     }, py::arg("name"), py::return_value_policy::reference_internal)
+    .def("all", (CraProxy (Model::*)()) &Model::all, py::keep_alive<0, 1>())
     .def("get_subchain",
          (ResidueSpan (Model::*)(const std::string&)) &Model::get_subchain,
          py::arg("name"), py::return_value_policy::reference_internal)
@@ -372,6 +389,7 @@ void add_mol(py::module& m) {
     .def("calculate_center_of_mass", [](const Model& self) {
         return calculate_center_of_mass(self).get();
     })
+    .def("clone", [](const Model& self) { return new Model(self); })
     .def("__repr__", [](const Model& self) {
         return tostr("<gemmi.Model ", self.name, " with ",
                      self.chains.size(), " chain(s)>");
@@ -397,7 +415,11 @@ void add_mol(py::module& m) {
         return py::make_iterator(self);
     }, py::keep_alive<0, 1>());
 
-  py::class_<Chain>(m, "Chain")
+  pyCraGenerator
+    .def("__iter__", [](CraProxy& self) { return py::make_iterator(self); },
+         py::keep_alive<0, 1>());
+
+  pyChain
     .def(py::init<std::string>())
     .def_readwrite("name", &Chain::name)
     .def("__len__", [](const Chain& ch) { return ch.residues.size(); })
@@ -444,12 +466,13 @@ void add_mol(py::module& m) {
     .def("first_conformer",
          (UniqProxy<Residue> (Chain::*)()) &Chain::first_conformer,
          py::keep_alive<0, 1>())
+    .def("clone", [](const Chain& self) { return new Chain(self); })
     .def("__repr__", [](const Chain& self) {
         return tostr("<gemmi.Chain ", self.name,
                      " with ", self.residues.size(), " res>");
     });
 
-  py::class_<ResidueSpan>(m, "ResidueSpan")
+  pyResidueSpan
     .def("__len__", &ResidueSpan::size)
     .def("__iter__", [](ResidueSpan& g) { return py::make_iterator(g); },
          py::keep_alive<0, 1>())
@@ -493,7 +516,7 @@ void add_mol(py::module& m) {
         return r + "]>";
     });
 
-  py::class_<ResidueGroup, ResidueSpan>(m, "ResidueGroup")
+  pyResidueGroup
     // need to duplicate it so it is visible
     .def("__getitem__", [](ResidueGroup& g, int index) -> Residue& {
         return g[normalize_index(index, g)];
@@ -523,7 +546,7 @@ void add_mol(py::module& m) {
                      self.size(), '>');
     });
 
-  py::class_<SeqId>(m, "SeqId")
+  pySeqId
     .def(py::init<int, char>())
     .def(py::init<const std::string&>())
     .def_readwrite("num", &SeqId::num)
@@ -533,7 +556,7 @@ void add_mol(py::module& m) {
         return tostr("<gemmi.SeqId ", self.str(), '>');
     });
 
-  py::class_<ResidueId>(m, "ResidueId")
+  pyResidueId
     .def(py::init<>())
     .def_readwrite("name", &ResidueId::name)
     .def_readwrite("seqid", &ResidueId::seqid)
@@ -543,11 +566,12 @@ void add_mol(py::module& m) {
         return tostr("<gemmi.ResidueId ", self.str(), '>');
     });
 
-  py::class_<Residue, ResidueId>(m, "Residue")
+  pyResidue
     .def(py::init<>())
     .def_readwrite("subchain", &Residue::subchain)
     .def_readwrite("entity_type", &Residue::entity_type)
     .def_readwrite("het_flag", &Residue::het_flag)
+    .def_readwrite("flag", &Residue::flag)
     .def_readwrite("label_seq", &Residue::label_seq)
     .def("__len__", [](const Residue& res) { return res.atoms.size(); })
     .def("__contains__", [](const Residue& res, const std::string& name) {
@@ -581,12 +605,13 @@ void add_mol(py::module& m) {
     .def("sole_atom", &Residue::sole_atom)
     .def("is_water", &Residue::is_water)
     .def("trim_to_alanine", (bool (*)(Residue&)) &trim_to_alanine)
+    .def("clone", [](const Residue& self) { return new Residue(self); })
     .def("__repr__", [](const Residue& self) {
         return tostr("<gemmi.Residue ", self.str(), " with ",
                      self.atoms.size(), " atoms>");
     });
 
-  py::class_<Atom>(m, "Atom")
+  pyAtom
     .def(py::init<>())
     .def_readwrite("name", &Atom::name)
     .def_readwrite("altloc", &Atom::altloc)
@@ -595,18 +620,13 @@ void add_mol(py::module& m) {
     .def_readwrite("pos", &Atom::pos)
     .def_readwrite("occ", &Atom::occ)
     .def_readwrite("b_iso", &Atom::b_iso)
-    .def_readwrite("u11", &Atom::u11)
-    .def_readwrite("u22", &Atom::u22)
-    .def_readwrite("u33", &Atom::u33)
-    .def_readwrite("u12", &Atom::u12)
-    .def_readwrite("u13", &Atom::u13)
-    .def_readwrite("u23", &Atom::u23)
+    .def_readwrite("aniso", &Atom::aniso)
     .def_readwrite("serial", &Atom::serial)
     .def_readwrite("flag", &Atom::flag)
     .def("is_hydrogen", &Atom::is_hydrogen)
     .def("has_altloc", &Atom::has_altloc)
-    .def("has_anisou", &Atom::has_anisou)
-    .def("b_iso_from_aniso", &Atom::b_iso_from_aniso)
+    .def("b_eq", &Atom::b_eq)
+    .def("clone", [](const Atom& self) { return new Atom(self); })
     .def("__repr__", [](const Atom& self) {
         std::string r = "<gemmi.Atom " + self.name;
         if (self.altloc) {
@@ -620,6 +640,7 @@ void add_mol(py::module& m) {
         return r + buf;
     });
 
+  m.def("calculate_b_est", &calculate_b_est);
   m.def("calculate_angle", &calculate_angle,
         "Input: three points. Output: angle in radians.");
   m.def("calculate_dihedral", &calculate_dihedral,
