@@ -19,6 +19,29 @@ static std::string triple(double x, double y, double z) {
   return std::string(buf);
 }
 
+template<typename T> void add_smat33(py::module& m, const char* name) {
+  using M = SMat33<T>;
+  py::class_<M>(m, name)
+    .def(py::init([](T u11, T u22, T u33, T u12, T u13, T u23) {
+           return M{u11, u22, u33, u12, u13, u23};
+         }), py::arg("u11"), py::arg("u22"), py::arg("u33"),
+             py::arg("u12"), py::arg("u13"), py::arg("u23"))
+    .def_readwrite("u11", &M::u11)
+    .def_readwrite("u22", &M::u22)
+    .def_readwrite("u33", &M::u33)
+    .def_readwrite("u12", &M::u12)
+    .def_readwrite("u13", &M::u13)
+    .def_readwrite("u23", &M::u23)
+    .def("as_mat33", &M::as_mat33)
+    .def("trace", &M::trace)
+    .def("nonzero", &M::nonzero)
+    .def("determinant", &M::determinant)
+    .def("inverse", &M::inverse)
+    .def("transformed_by", &M::transformed_by)
+    .def("calculate_eigenvalues", &M::calculate_eigenvalues)
+    ;
+}
+
 void add_unitcell(py::module& m) {
   py::class_<Vec3>(m, "Vec3")
     .def(py::init<double,double,double>())
@@ -64,6 +87,10 @@ void add_unitcell(py::module& m) {
                "             [" + triple(a[1][0], a[1][1], a[1][2]) + "]\n"
                "             [" + triple(a[2][0], a[2][1], a[2][2]) + "]>";
     });
+
+  add_smat33<double>(m, "SMat33d");
+  add_smat33<float>(m, "SMat33f");
+
   py::class_<Transform>(m, "Transform")
     .def(py::init<>())
     .def_readonly("mat", &Transform::mat)
@@ -105,13 +132,9 @@ void add_unitcell(py::module& m) {
 
   py::class_<UnitCell>(m, "UnitCell")
     .def(py::init<>())
-    .def(py::init([](double a, double b, double c,
-                     double alpha, double beta, double gamma) {
-           UnitCell cell;
-           cell.set(a, b, c, alpha, beta, gamma);
-           return cell;
-         }), py::arg("a"), py::arg("b"), py::arg("c"),
-             py::arg("alpha"), py::arg("beta"), py::arg("gamma"))
+    .def(py::init<double,double,double,double,double,double>(),
+         py::arg("a"), py::arg("b"), py::arg("c"),
+         py::arg("alpha"), py::arg("beta"), py::arg("gamma"))
     .def_readonly("a", &UnitCell::a)
     .def_readonly("b", &UnitCell::b)
     .def_readonly("c", &UnitCell::c)
